@@ -2,7 +2,7 @@
 
 # EnPT, EnMAP Processing Tool - A Python package for pre-processing of EnMAP Level-1B data
 #
-# Copyright (C) 2019  Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
+# Copyright (C) 2018-2021 Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
 # (GFZ Potsdam, danschef@gfz-potsdam.de), Niklas Bohn (GFZ Potsdam, nbohn@gfz-potsdam.de),
 # Stéphane Guillaso (GFZ Potsdam, stephane.guillaso@gfz-potsdam.de)
 #
@@ -62,6 +62,54 @@ __author__ = 'Daniel Scheffler'
 path_enptlib = os.path.dirname(pkgutil.get_loader("enpt").path)
 path_options_default = os.path.join(path_enptlib, 'options', 'options_default.json')
 
+try:
+    # from acwater.acwater import polymer_ac_enmap
+    path_polymer = os.path.abspath(os.path.join(os.path.dirname(pkgutil.get_loader("polymer").path), os.pardir))
+except AttributeError:
+    path_polymer = ''
+
+config_for_testing_water = dict(
+    path_l1b_enmap_image=os.path.abspath(
+        os.path.join(path_enptlib, '..', 'tests', 'data', 'EnMAP_Level_1B',
+                     # Arcachon
+                     'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip'
+
+                     # Arcachon full tile 2
+                     # 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z.zip'
+                     )),
+    # path_l1b_enmap_image_gapfill=os.path.abspath(
+    #     os.path.join(path_enptlib, '..', 'tests', 'data', 'EnMAP_Level_1B',
+    #                  'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip')),
+    path_dem=os.path.abspath(
+        os.path.join(path_enptlib, '..', 'tests', 'data',
+                     'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2'
+                     '__DEM_ASTER.bsq')),
+    log_level='DEBUG',
+    output_dir=os.path.join(path_enptlib, '..', 'tests', 'data', 'test_outputs'),
+    disable_progress_bars=False,
+    is_dummy_dataformat=False,
+    auto_download_ecmwf=True,
+    average_elevation=0,
+    deadpix_P_algorithm='spectral',
+    deadpix_P_interp_spatial='linear',
+    deadpix_P_interp_spectral='linear',
+    enable_keystone_correction=False,
+    enable_vnir_swir_coreg=False,
+    n_lines_to_append=None,
+    ortho_resampAlg='gauss',
+    run_deadpix_P=True,
+    run_smile_P=False,
+    scale_factor_boa_ref=10000,
+    scale_factor_toa_ref=10000,
+    enable_ac=True,
+    mode_ac='combined',
+    polymer_root=path_polymer,
+    threads=-1,
+    blocksize=100,
+    vswir_overlap_algorithm='swir_only',
+    CPUs=16
+)
+
 
 config_for_testing = dict(
     path_l1b_enmap_image=os.path.abspath(
@@ -76,6 +124,7 @@ config_for_testing = dict(
     disable_progress_bars=True,
     is_dummy_dataformat=True,
     enable_ac=False,
+    ortho_resampAlg='bilinear',
     CPUs=16
 )
 
@@ -100,6 +149,9 @@ config_for_testing_dlr = dict(
 
                      # Arcachon full tile 3, reprocessed 05/2020
                      # 'ENMAP01-____L1B-DT000400126_20170218T110119Z_003_V000204_20200508T124425Z.zip'
+
+                     # Arcachon tile 3 (full), downloaded from enmap.org
+                     # 'L1B_Arcachon_3__enmap.org.zip',
                      )),
     # path_l1b_enmap_image_gapfill=os.path.abspath(
     #     os.path.join(path_enptlib, '..', 'tests', 'data', 'EnMAP_Level_1B',
@@ -134,6 +186,7 @@ config_for_testing_dlr = dict(
     enable_absolute_coreg=True,
     path_reference_image=os.path.join(path_enptlib, '..', 'tests', 'data', 'T30TXQ_20170218T110111_B05__sub.tif'),
     enable_ac=True,
+    mode_ac='land',
     CPUs=32,
     ortho_resampAlg='gauss',
     vswir_overlap_algorithm='swir_only'
@@ -217,16 +270,36 @@ class EnPTConfig(object):
         :key path_reference_image:
             Reference image for co-registration.
 
+        :key polymer root:
+            Polymer root directory (that contains the subdirectory for ancillary data).
+
         :key enable_ac:
             Enable atmospheric correction using SICOR algorithm (default: True).
             If False, the L2A output contains top-of-atmosphere reflectance.
 
-        :key enable_cloud_screening:
-            Enable cloud screening during atmospheric correction
+        :key mode_ac:
+            3 modes to determine which atmospheric correction is applied at which surfaces (default: land):
+            - 'land': SICOR (developed for land surfaces is applied to land AND water surfaces
+            - 'water': POLYMER (developed for water surfaces) is applied to water only
+                       (land surfaces are no included in the L2A product)
+            - 'combined': SICOR is applied to land and POLYMER is applied to water surfaces;
+                          NOTE that this may result in edge effects, e.g., at coastlines
+
+        :key auto_download_ecmwf:
+            Automatically download ECMWF AUX data when running Polymer atmospheric correction for water surfaces
 
         :key scale_factor_boa_ref:
             Scale factor to be applied to BOA reflectance result
 
+        :key threads:
+            number of threads for multiprocessing of blocks (see bellow):
+            - 'threads = 0': for single thread
+            - 'threads < 0': for as many threads as there are CPUs
+            - 'threads > 0': gives the number of threads
+
+        :key blocksize:
+            block size for multiprocessing
+
         :key run_smile_P:
             Enable extra smile detection and correction (provider smile coefficients are ignored)
 
@@ -256,7 +329,6 @@ class EnPTConfig(object):
         :key target_coord_grid:
             Custom target coordinate grid where the output is resampled to ([x0, x1, y0, y1], e.g., [0, 30, 0, 30])
         """
-
         # fixed attributes
         self.version = __version__
         self.versionalias = __versionalias__
@@ -321,9 +393,13 @@ class EnPTConfig(object):
         self.path_reference_image = gp('path_reference_image')
 
         # atmospheric_correction
+        self.polymer_root = gp('polymer_root')
         self.enable_ac = gp('enable_ac')
-        self.enable_cloud_screening = gp('enable_cloud_screening')
+        self.mode_ac = gp('mode_ac')
+        self.auto_download_ecmwf = gp('auto_download_ecmwf')
         self.scale_factor_boa_ref = gp('scale_factor_boa_ref')
+        self.threads = gp('threads')
+        self.blocksize = gp('blocksize')
 
         # smile
         self.run_smile_P = gp('run_smile_P')
@@ -349,11 +425,12 @@ class EnPTConfig(object):
         EnPTValidator(allow_unknown=True, schema=enpt_schema_config_output).validate(self.to_dict())
 
         # check if given paths point to existing files
-        paths = {k: v for k, v in self.__dict__.items() if k.startswith('path_')}
-        for k, fp in paths.items():
-            if fp and not os.path.isfile(fp):
-                raise FileNotFoundError("The file path provided at the '%s' parameter does not point to an existing "
-                                        "file (%s)." % (k, fp))
+        if os.getenv('IS_ENPT_GUI_TEST') != "1":
+            paths = {k: v for k, v in self.__dict__.items() if k.startswith('path_')}
+            for k, fp in paths.items():
+                if fp and not os.path.isfile(fp):
+                    raise FileNotFoundError("The file path provided at the '%s' parameter does not point "
+                                            "to an existing file (%s)." % (k, fp))
 
         if not self.path_dem:
             warnings.warn('No digital elevation model provided. Note that this may cause uncertainties, e.g., '
@@ -538,7 +615,7 @@ def python_to_json(value):
 
 class EnPTValidator(Validator):
     def __init__(self, *args, **kwargs):
-        """
+        """Get an instance of EnPTValidator.
 
         :param args:    Arguments to be passed to cerberus.Validator
         :param kwargs:  Keyword arguments to be passed to cerberus.Validator
@@ -557,7 +634,6 @@ def get_options(target: str, validation: bool = True):
     :param validation:  True / False, whether to validate options read from files or not
     :return: dictionary with options
     """
-
     if os.path.isfile(target):
         with open(target, "r") as fl:
             options = json_to_python(json.loads(jsmin(fl.read())))
