@@ -2,7 +2,7 @@
 
 # EnPT, EnMAP Processing Tool - A Python package for pre-processing of EnMAP Level-1B data
 #
-# Copyright (C) 2019  Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
+# Copyright (C) 2018-2021 Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
 # (GFZ Potsdam, danschef@gfz-potsdam.de), Niklas Bohn (GFZ Potsdam, nbohn@gfz-potsdam.de),
 # Stéphane Guillaso (GFZ Potsdam, stephane.guillaso@gfz-potsdam.de)
 #
@@ -82,9 +82,14 @@ enpt_schema_input = dict(
             atmospheric_correction=dict(
                 type='dict', required=False,
                 schema=dict(
+                    polymer_root=dict(type='string', required=False),
                     enable_ac=dict(type='boolean', required=False),
-                    enable_cloud_screening=dict(type='boolean', required=False),
+                    mode_ac=dict(type='string', required=False, allowed=['land', 'water', 'combined']),
+                    auto_download_ecmwf=dict(type='boolean', required=False),
                     scale_factor_boa_ref=dict(type='integer', required=False, min=1),
+                    threads=dict(type='integer', required=False),
+                    blocksize=dict(type='integer', required=False),
+
                 )),
 
             smile=dict(
@@ -151,9 +156,13 @@ parameter_mapping = dict(
     path_reference_image=('processors', 'geometry', 'path_reference_image'),
 
     # processors > atmospheric_correction
+    polymer_root=('processors', 'atmospheric_correction', 'polymer_root'),
     enable_ac=('processors', 'atmospheric_correction', 'enable_ac'),
-    enable_cloud_screening=('processors', 'atmospheric_correction', 'enable_cloud_screening'),
+    mode_ac=('processors', 'atmospheric_correction', 'mode_ac'),
+    auto_download_ecmwf=('processors', 'atmospheric_correction', 'auto_download_ecmwf'),
     scale_factor_boa_ref=('processors', 'atmospheric_correction', 'scale_factor_boa_ref'),
+    threads=('processors', 'atmospheric_correction', 'threads'),
+    blocksize=('processors', 'atmospheric_correction', 'blocksize'),
 
     # processors > smile
     run_smile_P=('processors', 'smile', 'run_processor'),
@@ -175,8 +184,7 @@ parameter_mapping = dict(
 
 def get_updated_schema(source_schema, key2update, new_value):
     def deep_update(schema, key2upd, new_val):
-        """Return true if update, else false"""
-
+        """Return true if update, else false."""
         for key in schema:
             if key == key2upd:
                 schema[key] = new_val
