@@ -83,7 +83,7 @@ class Geometry_Transformer(SensorMapGeometryTransformer):
                         area_definition: AreaDefinition = None):
         data_sensorgeo = GeoArray(path_or_geoarray_sensorgeo)
 
-        if data_sensorgeo.is_map_geo:
+        if data_sensorgeo.is_map_geo and not data_sensorgeo.is_rotated:
             raise RuntimeError('The dataset to be transformed into map geometry already represents map geometry.')
 
         # run transformation (output extent/area definition etc. is internally computed from the geolayers if not given)
@@ -135,7 +135,7 @@ class Geometry_Transformer_3D(SensorMapGeometryTransformer3D):
                         ) -> Tuple[np.ndarray, tuple, str]:
         data_sensorgeo = GeoArray(path_or_geoarray_sensorgeo)
 
-        if data_sensorgeo.is_map_geo:
+        if data_sensorgeo.is_map_geo and not data_sensorgeo.is_rotated:
             raise RuntimeError('The dataset to be transformed into map geometry already represents map geometry.')
 
         # run transformation (output extent/area definition etc. is internally computed from the geolayers if not given)
@@ -298,7 +298,7 @@ class RPC_Geolayer_Generator(object):
         :param elevation:               digital elevation model in map geometry (file path or instance of GeoArray) OR
                                         average elevation in meters as integer or float
         :param enmapIm_cornerCoords:    corner coordinates as tuple of lon/lat pairs
-        :param enmapIm_dims_sensorgeo:  dimensions of the EnMAP image in sensor geometry (rows, colunms)
+        :param enmapIm_dims_sensorgeo:  dimensions of the EnMAP image in sensor geometry (rows, columns)
         """
         self.row_off = rpc_coeffs['row_off']
         self.col_off = rpc_coeffs['col_off']
@@ -402,7 +402,7 @@ class RPC_Geolayer_Generator(object):
     def _denormalize_image_coordinates(self,
                                        row_norm: np.ndarray,
                                        col_norm: np.ndarray) -> (np.ndarray, np.ndarray):
-        """De-normalize norrmalized sensor geometry coordinates to get valid image coordinates.
+        """De-normalize normalized sensor geometry coordinates to get valid image coordinates.
 
         :param row_norm:    normalized rows
         :param col_norm:    normalized columns
@@ -541,6 +541,15 @@ class RPC_Geolayer_Generator(object):
 global_dem_sensorgeo: Optional[GeoArray] = None
 
 
+def _initialize_mp(elevation: Union[float, np.ndarray]):
+    """Declare global variables needed for RPC_3D_Geolayer_Generator._compute_geolayer_for_unique_coeffgroup().
+
+    :param elevation:   elevation - either as average value (float) or as a numpy array
+    """
+    global global_dem_sensorgeo
+    global_dem_sensorgeo = elevation
+
+
 class RPC_3D_Geolayer_Generator(object):
     """Class for creating band- AND pixel-wise longitude/latitude arrays based on rational polynomial coeff. (RPC)."""
 
@@ -650,8 +659,10 @@ class RPC_3D_Geolayer_Generator(object):
                 # FIXME: pickling back large lon/lat arrays to the main process may be an issue on small machines
                 #        -> results could be temporarily written to disk in that case
                 # NOTE: With the small test dataset pickling has only a small effect on processing time.
-                with Pool(self.CPUs) as pool:
+                with Pool(self.CPUs, initializer=_initialize_mp, initargs=[self.elevation]) as pool:
                     results = list(pool.imap_unordered(self._compute_geolayer_for_unique_coeffgroup, kwargs_list))
+                    pool.close()  # needed for coverage to work in multiprocessing
+                    pool.join()
 
             else:
                 # singleprocessing
